CapabilityAllowlistEntry

Struct CapabilityAllowlistEntry 

pub struct CapabilityAllowlistEntry {
    pub source_moniker: Option<String>,
    pub source_name: Option<String>,
    pub capability: Option<AllowlistedCapability>,
    pub target_monikers: Option<Vec<String>>,
    pub source: Option<Ref>,
    /* private fields */
}
Defines a single capability policy entry in the set of capability policy allowlists.

Fields

source_moniker: Option<String>

The source_moniker represents the origin of a capability. The source_moniker is either a moniker or ‘<component_manager>’.

source_name: Option<String>

The source name of this particular capability.

capability: Option<AllowlistedCapability>

Represents the type of capability that is being restricted along with any other properties required by a particular capability type.

target_monikers: Option<Vec<String>>

The set of components, described by either exact monikers, realm, or collection, that are allowed to use this specific capability.

source: Option<Ref>

The original source type of this capability, self or framework.