DebugRegistrationAllowlistEntry

Struct DebugRegistrationAllowlistEntry 

pub struct DebugRegistrationAllowlistEntry {
    pub name: Option<String>,
    pub debug: Option<AllowlistedDebugRegistration>,
    pub moniker: Option<String>,
    pub environment_name: Option<String>,
    /* private fields */
}
Defines a capability policy entry in the set of debug capability policy allowlists.

Fields

name: Option<String>

The name of the capability as it’s registered in the environment.

debug: Option<AllowlistedDebugRegistration>

Represents the type of capability that is being restricted along with any other properties required by a particular capability type.

moniker: Option<String>

The moniker of the component which is allowed to register this capability in its environment’s debug sction.

environment_name: Option<String>

Name of the environment where this capability can be registered.