EventStreamRouteMetadata

Struct EventStreamRouteMetadata 

pub struct EventStreamRouteMetadata {
    pub scope_moniker: Option<String>,
    pub scope: Option<Vec<Ref>>,
    /* private fields */
}
This value is used internally by event stream routers, to carry information pertinent to the route.

Fields

scope_moniker: Option<String>

The moniker of the component that has set a scope on this event stream. Unset if there is no scope on the event stream.

scope: Option<Vec<Ref>>

The scope(s) from which the consumer of this event stream will be able to observe events. Relative to the scope_moniker. Unset if there is no scope on the event stream.