JobPolicyAllowlists

Struct JobPolicyAllowlists 

pub struct JobPolicyAllowlists {
    pub ambient_mark_vmo_exec: Option<Vec<String>>,
    pub main_process_critical: Option<Vec<String>>,
    pub create_raw_processes: Option<Vec<String>>,
    /* private fields */
}
Allowlists for Zircon job policy.

Fields

ambient_mark_vmo_exec: Option<Vec<String>>

Allowlist entry monikers for components allowed to be given the ZX_POL_AMBIENT_MARK_VMO_EXEC job policy.

Components must request this policy by including “job_policy_ambient_mark_vmo_exec: true” in their CML’s program section and must be using the ELF runner. This is equivalent to the v1 ‘deprecated-ambient-replace-as-executable’ feature.

main_process_critical: Option<Vec<String>>

Allowlist entry monikers for components allowed to have their original process marked as critical to component_manager’s job.

Components must request this critical marking by including “main_process_critical: true” in their CML’s program section and must be using the ELF runner.

create_raw_processes: Option<Vec<String>>

Allowlist entry monikers for components allowed to call zx_process_create directly (e.g., do not have ZX_POL_NEW_PROCESS set to ZX_POL_ACTION_DENY).

Components must request this policy by including “job_policy_create_raw_processes: true” in their manifest’s program object and must be using the ELF runner.