pub struct StorageBackingDirectory {
pub capability: Option<ComponentCapability>,
pub moniker: Option<String>,
pub backing_dir_subdir: Option<String>,
pub storage_subdir: Option<String>,
pub storage_source_moniker: Option<String>,
/* private fields */
}Fields
capability: Option<ComponentCapability>moniker: Option<String>backing_dir_subdir: Option<String>storage_subdir: Option<String>storage_source_moniker: Option<String>Trait Implementations
Sourceimpl Clone for StorageBackingDirectory
impl Clone for StorageBackingDirectory
Sourcefn clone(&self) -> StorageBackingDirectory
fn clone(&self) -> StorageBackingDirectory
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StorageBackingDirectory
impl Debug for StorageBackingDirectory
Sourceimpl<D> Decode<StorageBackingDirectory, D> for StorageBackingDirectorywhere
D: ResourceDialect,
impl<D> Decode<StorageBackingDirectory, D> for StorageBackingDirectorywhere
D: ResourceDialect,
Sourcefn new_empty() -> StorageBackingDirectory
fn new_empty() -> StorageBackingDirectory
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for StorageBackingDirectory
impl Default for StorageBackingDirectory
Sourcefn default() -> StorageBackingDirectory
fn default() -> StorageBackingDirectory
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<StorageBackingDirectory, D> for &StorageBackingDirectorywhere
D: ResourceDialect,
impl<D> Encode<StorageBackingDirectory, D> for &StorageBackingDirectorywhere
D: ResourceDialect,
Sourceimpl PartialEq for StorageBackingDirectory
impl PartialEq for StorageBackingDirectory
Sourceimpl TypeMarker for StorageBackingDirectory
impl TypeMarker for StorageBackingDirectory
Sourcetype Owned = StorageBackingDirectory
type Owned = StorageBackingDirectory
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for StorageBackingDirectory
impl ValueTypeMarker for StorageBackingDirectory
Sourcetype Borrowed<'a> = &'a StorageBackingDirectory
type Borrowed<'a> = &'a StorageBackingDirectory
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<StorageBackingDirectory as TypeMarker>::Owned,
) -> <StorageBackingDirectory as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<StorageBackingDirectory as TypeMarker>::Owned, ) -> <StorageBackingDirectory as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for StorageBackingDirectory
impl StructuralPartialEq for StorageBackingDirectory